==> cx88-1.1.0.tar.gz: cx88-1.1.0/client/analog/cx88_analog_driver.h <==
/*-
 * Copyright 2008 Jason Harmening
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */

#ifndef __CX88_ANALOG_DRIVER_H__
#define __CX88_ANALOG_DRIVER_H__

#include <pthread.h>
#include <sys/ioctl.h>
#include "avb_driver.h"
#include "tuner_devnode_device.h"
#include "cx88_video_ioctl.h"
#include "cx88_audio_ioctl.h"
#include "cx88_driver.h"

class cx88_analog_driver
   : public cx88_driver
{
   public:

      enum cx88_analog_mode
      {
         CX88_ANALOG_MODE_VIDEO, 
         CX88_ANALOG_MODE_AUDIO
      };
      
      cx88_analog_driver(
         cx88_xml_config &cx88conf,
         tuner_config &tunerconf,
         const char *devnode,
         capvec &captures,
         cx88_analog_mode mode,
         cx88_analog_driver *slave,
         cx88_analog_driver *pip_driver,
         int &error);
      
      virtual ~cx88_analog_driver(void);
            
   protected:
            
      virtual int capture(const string &channel_string, cx88_capture_params &params);
           
      virtual int get_info(string &info);
      
      virtual double get_signal_strength(void);
           
      virtual int create_i2c_drivers(void) 
      {
         return 0;
      }
      
      virtual void destroy_i2c_drivers(void) {}
           
      virtual int set_channel_options(avb_channel &channel) 
      {
         return 0;
      } 

      virtual int set_format_options(cx88_video_format &format) 
      {
         return 0;
      }
      
      virtual int set_format_options(cx88_audio_format &format) 
      {
         return 0;
      }
      
      virtual int set_config_options(cx88_video_config &config) 
      {
         return 0;
      }
      
      virtual int set_config_options(cx88_audio_config &config) 
      {
         return 0;
      }
      
      virtual int set_capture_options(cx88_video_capture &capture)
      {
         return 0;
      }
      
      cx88_analog_mode m_mode;
      
   private:
      
      int capture_audio(cx88_common_i2c_config &i2config, cx88_capture_params &params);
      int capture_video(cx88_common_i2c_config &i2config, cx88_capture_params &params);
      int change_channel(cx88_common_i2c_config &config, cx88_capture_params &params);
      int get_status(cx88_audio_status &status);
      int get_status(cx88_video_status &status);
      int set_audio_format(void);
      int set_video_format(cx88_video_format &format);
      
      avb_channel m_avb_channel;
      cx88_analog_driver *m_slave;
      cx88_analog_driver *m_pip_driver;
      bool m_slave_mode;
      bool m_pip_mode;
      uint8_t *m_buffer;
};

#endif

==> cx88-1.2.1.tar.gz: cx88-1.2.1/client/analog/cx88_analog_driver.h <==
/*-
 * Copyright 2008 Jason Harmening
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */

#ifndef __CX88_ANALOG_DRIVER_H__
#define __CX88_ANALOG_DRIVER_H__

#include <pthread.h>
#include <sys/ioctl.h>
#include "avb_driver.h"
#include "tuner_devnode_device.h"
#include "cx88_video_ioctl.h"
#include "cx88_audio_ioctl.h"
#include "cx88_driver.h"

class cx88_analog_driver
   : public cx88_driver
{
   public:

      enum cx88_analog_mode
      {
         CX88_ANALOG_MODE_VIDEO, 
         CX88_ANALOG_MODE_AUDIO
      };
      
      cx88_analog_driver(
         cx88_xml_config &cx88conf,
         tuner_config &tunerconf,
         const char *devnode,
         capvec &captures,
         cx88_analog_mode mode,
         cx88_analog_driver *slave,
         cx88_analog_driver *pip_driver,
         int &error);
      
      virtual ~cx88_analog_driver(void);
            
   protected:
            
      virtual int capture(const string &channel_string, cx88_capture_params &params);
           
      virtual int get_info(string &info);
      
      virtual double get_signal_strength(void);
           
      virtual int create_i2c_drivers(void) 
      {
         return 0;
      }
      
      virtual void destroy_i2c_drivers(void) {}
           
      virtual int set_channel_options(avb_channel &channel) 
      {
         return 0;
      } 

      virtual int set_format_options(cx88_video_format &format) 
      {
         return 0;
      }
      
      virtual int set_format_options(cx88_audio_format &format) 
      {
         return 0;
      }
      
      virtual int set_config_options(cx88_video_config &config) 
      {
         return 0;
      }
      
      virtual int set_config_options(cx88_audio_config &config) 
      {
         return 0;
      }
      
      virtual int set_capture_options(cx88_video_capture &capture)
      {
         return 0;
      }
      
      cx88_analog_mode m_mode;
      
   private:
      
      int capture_audio(cx88_capture_params &params);
      int capture_video(cx88_capture_params &params);
      int change_channel(cx88_capture_params &params);
      int get_status(cx88_audio_status &status);
      int get_status(cx88_video_status &status);
      int set_audio_format(void);
      int set_video_format(cx88_video_format &format);
      
      avb_channel m_avb_channel;
      cx88_analog_driver *m_slave;
      cx88_analog_driver *m_pip_driver;
      bool m_slave_mode;
      bool m_pip_mode;
      uint8_t *m_buffer;
};

#endif
